Issue class
- Implemented types
Constructors
-
factory
- Issue.badRequest([String? error])
-
factory
- Issue.forbidden()
-
factory
- Issue.none()
-
factory
- Issue.other(String error, {IssueLayer layer = IssueLayer.app, int statusCode = 0})
-
factory
- Issue.parsing([String? objectName])
-
factory
- Issue.requestCancelled()
-
factory
- Issue.server()
-
factory
- Issue.timeout([int? statusCode])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- issueLayer → IssueLayer
-
final
- issueType → IssueType
-
final
- message → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited